@@ -8,6 +8,8 @@ use Icinga\Repository\IniRepository;
 
 class RolesConfig extends IniRepository
 {
+    protected $sortRules = ['name' => ['order' => 'asc']];
+
     protected $configs = [
         'roles' => [
             'name'      => 'roles',
@@ -40,4 +42,9 @@ class RolesConfig extends IniRepository
 
         return $columns;
     }
+
+    protected function initializeSearchColumns(): array
+    {
+        return ['name'];
+    }
 }
