@@ -6,6 +6,8 @@ namespace Icinga\Data\Db;
 use DateTime;
 use DateTimeZone;
 use Exception;
+use Icinga\Data\Filter\FilterEqual;
+use Icinga\Data\Filter\FilterNotEqual;
 use Icinga\Data\Inspectable;
 use Icinga\Data\Inspection;
 use PDO;
@@ -205,8 +207,15 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
                     . 'ANSI_QUOTES,PIPES_AS_CONCAT,NO_ENGINE_SUBSTITUTION\'';
                 if (isset($adapterParamaters['charset'])) {
                     $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] .= ', NAMES ' . $adapterParamaters['charset'];
+                    if (trim($adapterParamaters['charset']) === 'latin1') {
+                        // Required for MySQL 8+ because we need PIPES_AS_CONCAT and
+                        // have several columns with explicit COLLATE instructions
+                        $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] .= ' COLLATE latin1_general_ci';
+                    }
+
                     unset($adapterParamaters['charset']);
                 }
+
                 $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] .= ", time_zone='" . $this->defaultTimezoneOffset() . "'";
                 $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] .=';';
                 $defaultPort = 3306;
@@ -259,14 +268,6 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
         return new static(ResourceFactory::getResourceConfig($name));
     }
 
-    /**
-     * @deprecated Use Connection::getDbAdapter() instead
-     */
-    public function getConnection()
-    {
-        return $this->dbAdapter;
-    }
-
     /**
      * Getter for the table prefix
      *
@@ -536,30 +537,57 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
         $value = $filter->getExpression();
 
         if (is_array($value)) {
-            if ($sign === '=') {
-                return $column . ' IN (' . $this->dbAdapter->quote($value) . ')';
-            } elseif ($sign === '!=') {
-                return sprintf('(%1$s NOT IN (%2$s) OR %1$s IS NULL)', $column, $this->dbAdapter->quote($value));
+            $comp = [];
+            $pattern = [];
+            foreach ($value as $val) {
+                if (strpos($val, '*') === false) {
+                    $comp[] = $val;
+                } else {
+                    $pattern[] = $this->renderFilterExpression(Filter::expression($column, $sign, $val));
+                }
             }
 
-            throw new ProgrammingError(
-                'Unable to render array expressions with operators other than equal or not equal'
-            );
-        } elseif ($sign === '=' && strpos($value, '*') !== false) {
+            $sql = $pattern;
+            if ($sign === '=') {
+                if (! empty($comp)) {
+                    $sql[] = $column . ' IN (' . $this->dbAdapter->quote($comp) . ')';
+                }
+
+                $operator = 'OR';
+            } elseif ($sign === '!=') {
+                if (! empty($comp)) {
+                    $sql[] = sprintf(
+                        '(%1$s NOT IN (%2$s) OR %1$s IS NULL)',
+                        $column,
+                        $this->dbAdapter->quote($comp)
+                    );
+                }
+
+                $operator = 'AND';
+            } else {
+                throw new ProgrammingError(
+                    'Unable to render array expressions with operators other than equal or not equal'
+                );
+            }
+
+            return count($sql) === 1 ? $sql[0] : '(' . implode(" $operator ", $sql) . ')';
+        } elseif ($sign === '='
+            && ! $filter instanceof FilterEqual
+            && $value !== null
+            && strpos($value, '*') !== false
+        ) {
             if ($value === '*') {
-                // We'll ignore such filters as it prevents index usage and because "*" means anything, so whether we're
-                // using a real column with a valid comparison here or just an expression which can only be evaluated to
-                // true makes no difference, except for performance reasons...
-                return new Zend_Db_Expr('TRUE');
+                return $column . ' IS NOT NULL';
             }
 
             return $column . ' LIKE ' . $this->dbAdapter->quote(preg_replace('~\*~', '%', $value));
-        } elseif ($sign === '!=' && strpos($value, '*') !== false) {
+        } elseif ($sign === '!='
+            && ! $filter instanceof FilterNotEqual
+            && $value !== null
+            && strpos($value, '*') !== false
+        ) {
             if ($value === '*') {
-                // We'll ignore such filters as it prevents index usage and because "*" means nothing, so whether we're
-                // using a real column with a valid comparison here or just an expression which cannot be evaluated to
-                // true makes no difference, except for performance reasons...
-                return new Zend_Db_Expr('FALSE');
+                return $column . ' IS NULL';
             }
 
             return sprintf(
