@@ -69,7 +69,6 @@ class FileCache
     public function store($file, $content)
     {
         if (! $this->enabled) {
-
             return false;
         }
 
@@ -87,26 +86,22 @@ class FileCache
     public function has($file, $newerThan = null)
     {
         if (! $this->enabled) {
-
             return false;
         }
 
         $filename = $this->filename($file);
 
         if (! file_exists($filename) || ! is_readable($filename)) {
-
             return false;
         }
 
         if ($newerThan === null) {
-
             return true;
         }
 
-        $info = stat($file);
+        $info = stat($filename);
 
         if ($info === false) {
-
             return false;
         }
 
@@ -159,6 +154,27 @@ class FileCache
         return $this->basedir . '/' . $file;
     }
 
+    /**
+     * Prepare a sub directory with the given name and return its path
+     *
+     * @param   string  $name
+     *
+     * @return  string|false    Returns FALSE in case the cache is not enabled or an error occurred
+     */
+    public function directory($name)
+    {
+        if (! $this->enabled) {
+            return false;
+        }
+
+        $path = $this->filename($name);
+        if (! is_dir($path) && ! @mkdir($path, octdec('1750'), true)) {
+            return false;
+        }
+
+        return $path;
+    }
+
     /**
      * Whether the given ETag matches a cached file
      *
@@ -206,6 +222,11 @@ class FileCache
             return false;
         }
 
+        if (preg_match('/([0-9a-f]{8}-[0-9a-f]{8}-[0-9a-f]{8})-\w+/i', $match, $matches)) {
+            // Removes compression suffixes as our custom algorithm can't handle compressed cache files anyway
+            $match = $matches[1];
+        }
+
         $etag = self::etagForFiles($files);
         return $match === $etag ? $etag : false;
     }
