@@ -59,7 +59,7 @@ class HostgroupQuery extends IdoQuery
                         END
                     END
                 END',
-            'host_state'    => 'CASE WHEN hs.has_been_checked = 0 OR (hs.has_been_checked IS NULL AND hs.hoststatus_id IS NOT NULL) THEN 99 ELSE hs.current_state END'
+            'host_state'    => 'CASE WHEN hs.has_been_checked = 0 OR hs.has_been_checked IS NULL THEN 99 ELSE hs.current_state END'
         ),
         'instances' => array(
             'instance_name' => 'i.instance_name'
@@ -112,7 +112,7 @@ class HostgroupQuery extends IdoQuery
                              END
                          END
                 END',
-            'service_state'     => 'CASE WHEN ss.has_been_checked = 0 OR (ss.has_been_checked IS NULL AND ss.servicestatus_id IS NOT NULL) THEN 99 ELSE ss.current_state END'
+            'service_state'     => 'CASE WHEN ss.has_been_checked = 0 OR ss.has_been_checked IS NULL THEN 99 ELSE ss.current_state END'
         )
     );
 
@@ -171,7 +171,7 @@ class HostgroupQuery extends IdoQuery
     protected function joinHosts()
     {
         $this->requireVirtualTable('members');
-        $this->select->joinLeft(
+        $this->select->join(
             array('h' => $this->prefix . 'hosts'),
             'h.host_object_id = ho.object_id',
             array()
@@ -184,7 +184,7 @@ class HostgroupQuery extends IdoQuery
     protected function joinHoststatus()
     {
         $this->requireVirtualTable('members');
-        $this->select->joinLeft(
+        $this->select->join(
             array('hs' => $this->prefix . 'hoststatus'),
             'hs.host_object_id = ho.object_id',
             array()
@@ -196,7 +196,7 @@ class HostgroupQuery extends IdoQuery
      */
     protected function joinInstances()
     {
-        $this->select->joinLeft(
+        $this->select->join(
             array('i' => $this->prefix . 'instances'),
             'i.instance_id = hg.instance_id',
             array()
@@ -208,11 +208,11 @@ class HostgroupQuery extends IdoQuery
      */
     protected function joinMembers()
     {
-        $this->select->joinLeft(
+        $this->select->join(
             array('hgm' => $this->prefix . 'hostgroup_members'),
             'hgm.hostgroup_id = hg.hostgroup_id',
             array()
-        )->joinLeft(
+        )->join(
             array('ho' => $this->prefix . 'objects'),
             'hgm.host_object_id = ho.object_id AND ho.is_active = 1 AND ho.objecttype_id = 1',
             array()
@@ -264,7 +264,7 @@ class HostgroupQuery extends IdoQuery
     {
         $this->requireVirtualTable('services');
         $this->requireVirtualTable('hoststatus');
-        $this->select->joinLeft(
+        $this->select->join(
             array('ss' => $this->prefix . 'servicestatus'),
             'ss.service_object_id = so.object_id',
             array()
