@@ -3,6 +3,8 @@
 
 namespace Icinga\Module\Monitoring\Object;
 
+use Icinga\Data\Filter\FilterEqual;
+use Icinga\Module\Monitoring\DataView\Servicestatus;
 use InvalidArgumentException;
 use Icinga\Module\Monitoring\Backend\MonitoringBackend;
 
@@ -101,7 +103,7 @@ class Service extends MonitoredObject
     /**
      * Get the data view
      *
-     * @return \Icinga\Module\Monitoring\DataView\ServiceStatus
+     * @return Servicestatus
      */
     protected function getDataView()
     {
@@ -171,8 +173,8 @@ class Service extends MonitoredObject
             'service_state',
             'service_state_type'
         ))
-            ->where('host_name', $this->host->getName())
-            ->where('service_description', $this->service);
+            ->whereEx(new FilterEqual('host_name', '=', $this->host->getName()))
+            ->whereEx(new FilterEqual('service_description', '=', $this->service));
     }
 
     /**
@@ -204,7 +206,7 @@ class Service extends MonitoredObject
                 $text = $translate ? mt('monitoring', 'PENDING') : 'pending';
                 break;
             default:
-                throw new InvalidArgumentException('Invalid service state \'%s\'', $state);
+                throw new InvalidArgumentException(sprintf('Invalid service state \'%s\'', $state));
         }
         return $text;
     }
