@@ -261,7 +261,11 @@
                 }
             }
 
-            if (! $autoSubmittedBy && typeof event.detail !== 'undefined' && "submittedBy" in event.detail) {
+            if (! $autoSubmittedBy
+                && event.detail !== null
+                && typeof event.detail === 'object'
+                && "submittedBy" in event.detail
+            ) {
                 $autoSubmittedBy = $(event.detail.submittedBy);
             }
 
